.. include:: ../README.rst

----------

.. toctree::
    :caption: xrtr
    :maxdepth: 1

    installing
    using

.. toctree::
    :caption: About the Project
    :maxdepth: 2

    reference/index
    contributing
    changelog
    authors
